@@ -56,7 +56,7 @@ def entry_point_refresh():
     #files = os.listdir(cwd)  # Get all the files in that directory
     #print("Files in %r: %s" % (cwd, files))
     
-        infile =  open(os.environ.get('ND_HOME') + '/CavAgent/interceptor_points.txt')
+        infile =  open(os.environ.get('ND_HOME') + '/python/CavAgent/interceptor_points.txt')
         outfile = open(os.path.join(path, './test.py'))
         temp = []
         for x in infile:
@@ -122,7 +122,7 @@ try:
     try:
         path_for_insProfile = myvars.get('path_profile').strip('\n')
     except:
-        path_for_insProfile = os.environ.get('ND_HOME') + "/CavAgent/instrumentationprofile.json"
+        path_for_insProfile = os.environ.get('ND_HOME') + "/python/CavAgent/instrumentationprofile.json"
 
 
     custom_methods_to_instrument_json = create_method_json(path_for_insProfile)["modules"]
@@ -134,7 +134,7 @@ except:
     pass
 
 def bootstrap(agent=None):
-    #print("AGENT BOOTSTRAP")
+    print("AGENT BOOTSTRAP")
     entry_point_refresh()
     import pythonagent.agent.internal.intercept_module
     reload(pythonagent.agent.internal.intercept_module)
@@ -193,6 +193,6 @@ def filewatchre(path, _agent):
     my_observer.schedule(my_event_handler, path, recursive=go_recursively)
 
     my_observer.start()
-filewatchre(os.environ.get('ND_HOME') + "/CavAgent/instrumentationprofile.json", _agent)
-filewatchre(os.environ.get('ND_HOME') + "/CavAgent/interceptor_points.txt", _agent)
+filewatchre(os.environ.get('ND_HOME') + "/python/CavAgent/instrumentationprofile.json", _agent)
+filewatchre(os.environ.get('ND_HOME') + "/python/CavAgent/interceptor_points.txt", _agent)
 
