@@ -6,14 +6,11 @@ from pythonagent.utils import get_current_timestamp_in_ms
 import os
 import configparser
 import time
-import logging
-
-logger = logging.getLogger('pythonagent.agent')
 
 #configParser = configparser.RawConfigParser()
 path = os.environ.get('ND_HOME')
-path = path + '/config/ndsettings.conf'
-logger.info("path of  NDC config : ", path)
+path = path + '/python/config/ndsettings.conf'
+print("path of  NDC config : ",path)
 #configParser.read(path)
 #path_for_insProfile = configParser.get('PYTHON_AGENT', 'path_profile')
 myvars = {}
@@ -27,18 +24,18 @@ try:
     path_for_insProfile = myvars.get('path_profile').strip('\n')
 except:
     #print("inside except")
-    path_for_insProfile= os.environ.get('ND_HOME') + "/CavAgent/instrumentationprofile.json"
-logger.debug('Profiler path at : {}'.format(path_for_insProfile))
+    path_for_insProfile= os.environ.get('ND_HOME') + "/python/CavAgent/instrumentationprofile.json"
+print('Profiler path at : ',path_for_insProfile)
 #custom_methods_to_instrument = create_method_array('/home/cavisson/shop/my-shop/instrumentationprofile.txt')
 custom_methods_to_instrument = create_method_array(path_for_insProfile)
-logger.debug("ALL custom modules(Instrument)-> ".format(custom_methods_to_instrument))
+print("ALL custom modules(Instrument)-> ", custom_methods_to_instrument)
 
 
 class MethodInterceptor(ExitCallInterceptor):
 
     def _custom_method(self, original_method, *args, **kwargs):
 
-        logger.info("\n\n\n\nInside Custom Method\n\n\n")
+        print("\n\n\n\nInside Custom Method\n\n\n")
         bt = self.bt
 
         if len(self.cls.__package__) >= 1:
@@ -49,8 +46,7 @@ class MethodInterceptor(ExitCallInterceptor):
 
         # print("Inside custom method")
 
-        #before_time = time.time_ns() // 1000000
-        before_time=get_current_timestamp_in_ms()
+        before_time = get_current_timestamp_in_ms() 
 
         # print("Before applying method call delay")
         # print("FQM: ", fqmforentry)
@@ -76,22 +72,21 @@ class MethodInterceptor(ExitCallInterceptor):
 
             finally:
 
-                #after_time = time.time_ns() // 1000000
-                after_time = get_current_timestamp_in_ms()
+                after_time = get_current_timestamp_in_ms() 
                 duration = after_time - before_time
-                logger.info("Duration Calculated: {}".format(duration))
+                print("Duration Calculated: ", duration)
 
                 try:
                     havoc_monitor.apply_method_invocation_failure(fqmforentry)
                 except Exception as e:
                     if isinstance(e, NDHavocException):
-                        logger.error("Havoc Exception {}".format(e))
+                        print("Havoc Exception {}".format(e))
                         status = 503
                         self.agent.method_exit(bt, fqmforentry, status, duration)
                         self.agent.set_current_status_code(503)
                         raise e
                     else:
-                        logger.error("Non-Havoc Exception {}".format(e))
+                        print("Non-Havoc Exception {}".format(e))
 
                 status = 0  # Needed for callouts only
                 if self.agent.cav_env == "AWS_LAMBDA":
@@ -112,23 +107,35 @@ class MethodInterceptor(ExitCallInterceptor):
 
 
 def intercept_instrumented_method(agent, mod):
-    logger.info("\n\n\n")
-    logger.info("intercept instrumented method")
-    logger.info("\n\n\n")
+    print("\n\n\n")
+    print("intercept instrumented method")
+    print("\n\n\n")
 
     for item in custom_methods_to_instrument:
+        #print("CUSTOM METHOD TO INSTRUMENT ", item)
+
+        #print("item name in custom_methods_to_intercept",item)
+        #agent.logger.info("Modulename: MethodInterceptor class inside intercept_instrumented_method item name in custom_methods_to_intercept {0}".format(item))
         check = item.split(".")
+        #print("array after split: ",check)
         if len(check) == 2:
+            #print("list to inst 2", check)
             try:
+                #print("ABOUT TO INTERCEPT INSTRUMENTED METHOD")
                 MethodInterceptor(agent, mod).attach(check[1], patched_method_name='_custom_method')
             except:
-                agent.logger.exception("Modulename: MethodInterceptor class inside intercept_instrumented_method,Instrumentation.__init__: class {} not present in module".format(check[1]))
+                #agent.logger.debug("Instrumentation.__init__: class ".format(check[1])+" not present in module")
+                agent.logger.exception('Modulename: MethodInterceptor class inside intercept_instrumented_method,Instrumentation.__init__: class ",check[1]," not present in module')
 
                 continue    
+               #MethodInterceptor(agent, mod).attach(check[1],wrapper_func='_custom_method')
         if len(check) == 3:
-            try:
+            #print("list to inst ", check)
+            #MethodInterceptor(agent, getattr(mod, check[1])).attach(check[2],wrapper_func='_custom_method')
+            try: 
                 MethodInterceptor(agent, getattr(mod, check[1])).attach(check[2],patched_method_name='_custom_method')
             except:
-                agent.logger.exception("Modulename: MethodInterceptor class inside intercept_instrumented_method, Instrumentation.__init__: method /class: {}.{} not present in module".format(check[1], check[2]))
+                agent.logger.exception('Modulename: MethodInterceptor class inside intercept_instrumented_method, Instrumentation.__init__: method /class: ",check[1],".",check[2]," not present in module"')
+                #agent.logger.debug("Instrumentation.__init__: method /class: ".format(check[1])+".".format(check[2])+" not present in module")
                 continue
 
