@@ -29,8 +29,7 @@ def find():
     p = psutil.Process(os.getpid())
     procname = p.name()
     nd_home = os.environ.get('ND_HOME')
-    pathforfile = nd_home + '/logs/'
-    #pathforfile =  "/opt/cavisson/netdiagnostics/logs/"
+    pathforfile = nd_home + '/python/logs/'
     filename = str(procname+"_AD.txt")
     file_to_open = os.path.join(pathforfile, filename)
     f = open(file_to_open, 'w')
