@@ -116,9 +116,8 @@ class ExitCallInterceptor(BaseInterceptor):
     def http_call_begin(self, bt, http_host, url):
         """Start an exit call.
         """
-        self.agent.logger.info("HTTP CALL BEGIN")
-        #current_time = time.time_ns() // 1000000
-        current_time = get_current_timestamp_in_ms()
+        print("HTTP CALL BEGIN")
+        current_time = get_current_timestamp_in_ms() 
         self.agent.get_transaction_context().tier_callout_start_time = current_time
         self.agent.get_transaction_context().tier_callout_type = "http"
         self.agent.get_transaction_context().backend_header = http_host
@@ -150,9 +149,8 @@ class ExitCallInterceptor(BaseInterceptor):
     def http_call_end(self, bt, exit_call, status=200):
         """End the exit call.
         """
-        self.agent.logger.info("HTTP CALL END")
-        #current_time = time.time_ns() // 1000000
-        current_time = get_current_timestamp_in_ms()
+        print("HTTP CALL END")
+        current_time = get_current_timestamp_in_ms() 
         start_time = self.agent.get_transaction_context().tier_callout_start_time
         duration = current_time - start_time
         method_name = "request" + "." + self.agent.get_transaction_context().http_request_type.lower()
@@ -178,7 +176,7 @@ class ExitCallInterceptor(BaseInterceptor):
 
         with self.log_exceptions():
             if exit_call:
-                self.agent.logger.info("Inside with self.log_exceptions(); if exit_call")
+                print("Inside with self.log_exceptions(); if exit_call")
                 backend_header = self.agent.get_transaction_context().backend_header
                 self.agent.method_exit_http_callout(zero_bt, method_name, backend_header, status, duration)  # METHOD EXIT FOR PROXY
                 self.agent.http_call_end(bt, exit_call)
