@@ -101,7 +101,7 @@ def dumpstacks():
 
 
     nd_home = os.environ.get('ND_HOME')
-    write_file = nd_home + '/logs/'
+    write_file = nd_home + '/python/logs/'
 
     write_json(write_file,
                datetime.now().strftime('thread_dump_%H_%M_%d_%m_%Y.txt'), thread1_details)
