@@ -14,7 +14,6 @@ def alloc_max_str(totaltobeleaked, memoryLeaksInSec, mbleakspertime, leaksINMB):
     Returns:
         a : String of size 'memory'
     '''
-    print("inside alloc max")
     i = 1
     a = ''
 
@@ -25,7 +24,6 @@ def alloc_max_str(totaltobeleaked, memoryLeaksInSec, mbleakspertime, leaksINMB):
         end_time = int((time.time()))+int(memoryLeaksInSec)
         try:
             a = ' ' * (int(i * int(((mbleakspertime))*MEGA)))
-            print("aaaa")
             li.append(a)
             if((psutil.virtual_memory().used >> 20) >= int(totaltobeleaked)):
                 break
@@ -33,7 +31,6 @@ def alloc_max_str(totaltobeleaked, memoryLeaksInSec, mbleakspertime, leaksINMB):
                 break
             
         except MemoryError:
-            print("BBBBBBBBBBBBBBB")
             break
         time.sleep(end_time-time.time())
         i += 1
@@ -41,7 +38,6 @@ def alloc_max_str(totaltobeleaked, memoryLeaksInSec, mbleakspertime, leaksINMB):
     return a
 
 def pmem():
-    print("inside pmem")
     '''
     Function to display memory statistics
     '''
@@ -52,7 +48,6 @@ def pmem():
 
 
 def memory_stress(totaltobeleaked, memoryLeaksInSec, totalDurationInSec, mbleakspertime, leaksINMB):
-    print("inside memory stress")
     '''
     Function to stress memory and display memory Stats
 
@@ -69,11 +64,9 @@ def memory_stress(totaltobeleaked, memoryLeaksInSec, totalDurationInSec, mbleaks
     return obj
 
 def apply_memory_leak(leaksINMB,totalDurationInSec, memoryLeaksInSec):
-    print("INSIDE apply_memory_leak")
     totaltobeleaked = int(int(psutil.virtual_memory().used >> 20) + int(leaksINMB))
-    print("totaltobeleaked", totaltobeleaked)
     mbleakspertime = int(leaksINMB)/(int(totalDurationInSec)/int(memoryLeaksInSec))
-    print("mbleakspertime", mbleakspertime)
     memory_stress(totaltobeleaked, memoryLeaksInSec, totalDurationInSec, mbleakspertime, leaksINMB)
 
 #need to create a check for memory should not be greater than total from psutil.virtual_memory().total
+
